@@ -2,8 +2,11 @@
 #  written by: Quintijn Hoogenboom (QH softwaretraining & advies)
 #  June 2003/August 2021
 #
-#pylint:disable=C0302, C0116, R0913, R0914, R1710, R0911, R0912, R0915, C0321, W0702, W0613
+#pylint:disable=C0302, C0116, R0913, R0914, R1710, R0911, R0912, R0915, C0321, W0702, W0613, W0602
 #pylint:disable=E1101
+#pylint:disable=C0209, R1728
+##TODO:
+#pylint:disable=W1514, R1732
 """This module contains actions that can be called from natlink grammars.
 
 The central functions are "doAction" and "doKeystroke".
@@ -33,14 +36,15 @@ import win32con
 
 import dtactions
 from dtactions import monitorfunctions
+from dtactions.sendkeys import sendkeys, sendsystemkeys
 # from dtactions import messagefunctions
 from dtactions import autohotkeyactions # for AutoHotkey support
 from dtactions.unimacro import unimacroutils
 from dtactions.unimacro import inivars
-
+# from dtactions.unimacro import actionclasses
 import natlink
-from natlink import natlinkutils
-from natlink.config import expand_path
+from natlinkcore import natlinkutils
+from natlinkcore.config import expand_path
 
 external_actions_modules = {}  # the modules, None if not available (for prog)
 external_action_instances = {} # the instances, None if not available (for hndle)
@@ -75,7 +79,7 @@ if not userDirectory.is_dir():
 userInifile = userDirectory/'unimacroactions.ini'
 if not userInifile.is_file():
     shutil.copy(sampleInifile, userInifile)
-print(f'unimacroactions, inifile: {userInifile}')
+# print(f'unimacroactions, inifile: {userInifile}')
 ## set ready the debug file
 debugFile = os.path.join(userDirectory, 'actions debug.txt')
 
@@ -214,18 +218,7 @@ def doAction(action, completeAction=None, pauseBA=None, pauseBK=None,
         if not ini:
             D('no valid inifile for actions')
             return
-        if modInfo is None:
-            try:
-                modInfo = natlink.getCurrentModule()
-                progInfo = unimacroutils.getProgInfo(modInfo)    
-                # print("modInfo through natlink: %s"% repr(modInfo))
-            except:
-                if progInfo is None:
-                    progInfo = autohotkeyactions.getProgInfo()
-           
-
-        if progInfo is None:
-            progInfo = unimacroutils.getProgInfo(modInfo=modInfo)
+        progInfo = unimacroutils.getProgInfo(modInfo=modInfo)
         #D('new progInfo: %s'% repr(progInfo))
         prog = progInfo.prog
         if sectionList is None:
@@ -465,10 +458,10 @@ def doKeystroke(action, hardKeys=None, pauseBK=None,
         # exactly 1 {key}:
         if debug > 5: D('exact action, hardKeys[0]: %s'% hardKeys[0])
         if hardKeys[0] == 'none':
-            natlinkutils.playString(action)  # the fastest way
+            sendkeys(action)
             return
         if hardKeys[0] == 'all':
-            natlinkutils.playString(action, natlinkutils.hook_f_systemkeys)
+            natlink.execScript('SendSystemKeys("{action}")')
             return
         m = BracesExtractKey.match(action)
         if m:
@@ -479,22 +472,22 @@ def doKeystroke(action, hardKeys=None, pauseBK=None,
                 if keyPart.find(mod)>0: keyPart = keyPart.replace(mod, '')
             if keyPart in hardKeys:
                 if debug > 3: D('doing "hard": |%s|'% action)
-                natlinkutils.playString(action, natlinkutils.hook_f_systemkeys)
+                sendsystemkeys(action)
                 return
             if debug > 3: D('doing "soft" (%s): |%s|'% (action, hardKeys))
-            natlinkutils.playString(action)  # fastest way
+            sendkeys(action)  # fastest way
             return
         # else:
         if debug > 3: D('doing "soft" (%s): |%s|'% (action, hardKeys))
-        natlinkutils.playString(action)
+        sendkeys(action)
         return
         
     # now proceed with more complex keystroke possibilities:
     if hardKeys[0]  == 'all':
-        natlinkutils.playString(action, natlinkutils.hook_f_systemkeys)
+        sendsystemkeys(action)
         return
     if hardKeys[0]  == 'none':
-        natlinkutils.playString(action)
+        sendkeys(action)
         return
     if hasBraces.search(action):
         keystrokeList = hasBraces.split(action)
@@ -505,7 +498,7 @@ def doKeystroke(action, hardKeys=None, pauseBK=None,
             doKeystroke(k, hardKeys=hardKeys, pauseBK = 0)
     else:
         if debug > 5: D('no braces keystrokes: |%s|' % action)
-        natlinkutils.playString(action)
+        sendkeys(action)
         
 def getMetaAction(a, sectionList=None, progInfo=None):
     if progInfo is None:
@@ -684,16 +677,16 @@ def getFromIni(keyword, default='',
 setting = getFromIni
 
 def get_external_module(prog):
-    """try to from natlink import actions_prog and put in external_actions_modules
+    """try to import actions_prog and put in external_actions_modules
     
     if module not there, put None in this external_actions_modules dict
     """
-    print(f'ask for program: "{prog}"')
+    # print(f'ask for program: "{prog}"')
     if prog in external_actions_modules:
         return external_actions_modules[prog]
     try:
         modname = '%s-actions'% str(prog)
-        _temp = __import__('actionclasses', fromlist=[modname])
+        _temp = __import__('dtactions.unimacro.actionclasses', fromlist=[modname])
         mod = getattr(_temp, modname)
         external_actions_modules[prog] = mod
         print('get_external_module, found actions module: %s'% modname)
@@ -704,7 +697,7 @@ def get_external_module(prog):
         # print 'get_external_module, no module found for: %s'% prog
  
 def get_instance_from_progInfo(progInfo):
-    """return the correct intances for progInfo
+    """return the correct instances for progInfo
     """
     prog = progInfo.prog
     hndle = progInfo.hndle
@@ -1079,7 +1072,7 @@ def do_NSM(**kw):
     prog = unimacroutils.getProgName(modInfo)
     if prog == 'natspeak':
         if modInfo[1].find('DragonPad') >= 0:
-            natlinkutils.playString('{alt+n}')
+            sendkeys('{alt+n}')
             return 1
     natlink.recognitionMimic(["NaturallySpeaking"])
     return unimacroutils.waitForWindowTitle(['DragonBar', 'Dragon-balk', 'Voicebar'],10,0.1)
@@ -1087,7 +1080,7 @@ def do_NSM(**kw):
 
 # shorthand for sendsystemkeys:
 def do_SSK(s, **kw):
-    natlinkutils.playString(s, natlinkutils.hook_f_systemkeys)
+    sendsystemkeys(s)
     return 1
 
 def do_S(s, **kw):
@@ -1407,14 +1400,14 @@ def do_U(n, **kw):
     # print 'U in: %s, Code: %s(type: %s)'% (n, Code, type(Code))
     if Code <256:
         # print 'do direct, ascii: %s, %s'% (Code, chr(Code))
-        natlinkutils.playString(chr(Code))
+        sendkeys(chr(Code))
         return
     u = chr(Code)
     # output through the clipboard with special code:
     unimacroutils.saveClipboard()
     #win32con.CF_UNICODETEXT = 13
     unimacroutils.setClipboard(u, format=13)
-    natlinkutils.playString('{ctrl+v}')
+    sendkeys('{ctrl+v}')
     unimacroutils.restoreClipboard()    
     return 1
                 
@@ -1885,7 +1878,7 @@ def YesNo(t, title=None, icon=32, alert=None, defaultToSecondButton=0, progInfo=
     if icon not in list(MsgboxConfirmIconDict.values()):
         raise ValueError("Unimacro actions Message, invalid value for icon: %s"% icon)
 
-    if isinstance(t, str):
+    if not isinstance(t, str):
         t = '\n'.join(t)
     tt = checkTextInMessage(t)
     title = title or "UnimacroActions Question"
@@ -2095,10 +2088,9 @@ def UnimacroBringUp(app, filepath=None, title=None, extra=None, modInfo=None, pr
         ## TODOQH
         # progFull, titleFull, hndle = natlink.getCurrentModule()
     
-        if windowCorrespondsToApp(app, appName, prog, title):
-            if debug > 1: D('already in this app: %s'% app)
-            if app not in bringups:
-                bringups[app] = (prog, title, hndle)
+        if debug > 1: D('already in this app: %s'% app)
+        if app not in bringups:
+            bringups[app] = (prog, title, hndle)
             return 1
     
         if app in bringups:
@@ -2313,6 +2305,6 @@ else:
 if __name__ == '__main__':
     _s = 551345646373737373
     do_SCLIP(_s)
-    # UnimacroBringUp("edit", r"C:\NatlinkGIT3\Unimacro\_lines.py")
+    # UnimacroBringUp("edit", r"C:\Users\Gebruiker\Documents\.natlink\UnimacroGrammars\_brackets.txt")
     
     
\ No newline at end of file
