@@ -11,7 +11,7 @@
 Previous this was natlinkutilsqh.py in unimacro
 
 """
-#pylint:disable=C0302, C0116, C0321, R0912, R0913, R0914, R0915, W0613
+#pylint:disable=C0302, C0116, C0321, R0912, R0913, R0914, R0915, W0613, C0209, W0602
 #pylint:disable=E1101
 import time
 import re
@@ -19,24 +19,22 @@ import os
 import os.path
 import sys
 import collections
-
+from pathlib import Path
 import win32gui
 import win32clipboard
+import win32con
 # import pywintypes
 
 from dtactions import monitorfunctions  # elaborated version QH
 from dtactions import autohotkeyactions
 
 import natlink
-from natlink import natlinkutils
-from natlink import natlinkstatus
+from natlinkcore import natlinkutils
+from natlinkcore import natlinkstatus
 status = natlinkstatus.NatlinkStatus()
 
 DEBUG = 0
-
-# status = natlinkstatus.NatlinkStatus()
-
-# errors for (mainly) the commando grammar:
+# errors for (mainly) the command grammar:
 
 class NatlinkCommandError(Exception):
     """NatlinkCommandError"""
@@ -54,9 +52,12 @@ shortWaitFactor = 0.3                 # times 10 for long wait
 #debugMode 0 = not, -1 == dvcMode, 1 is light, 2 = normal, 3 = heavy
 debugMode = 1
 
+pendingExecScripts = []
+
 ProgInfo = collections.namedtuple('ProgInfo', 'progpath prog title toporchild classname hndle'.split(' '))
 
 
+
 # class CaseInsensitiveSet(set):
 #     """makes the comparison for adding new elements case insensitive
 #     Adding takes the capitalisation of the first item added
@@ -68,7 +69,6 @@ ProgInfo = collections.namedtuple('ProgInfo', 'progpath prog title toporchild cl
 
 def getLanguage():
     """get current language, 3 characters
-
     """
     return status.get_language()
 
@@ -113,10 +113,10 @@ def getCurrentModuleSafe(nWait=5, waitingTime=0.01):
         modInfo = natlink.getCurrentModule()
         waited = (i+1)*waitingTime
         if modInfo:
-            print('getCurrentModuleSafe, found modInfo after %s seconds'% waited)
+            print(f'getCurrentModuleSafe, found modInfo after {waited} seconds')
             return modInfo
 
-    print('getCurrentModuleSafe, could not find modInfo after %s seconds'% modInfo)
+    print(f'getCurrentModuleSafe, could not find modInfo after {waited} seconds')
     return None
 
 def matchModule(modName, wantedTitle = None, modInfo=None, titleExact=0, caseExact=0):
@@ -202,11 +202,12 @@ def getProgName(modInfo=None):
         modInfo = natlink.getCurrentModule()
     return modInfo[0]
 
-ProgInfo = collections.namedtuple('ProgInfo', 'progpath prog title toporchild classname hndle'.split(' '))
+# ProgInfo = collections.namedtuple('ProgInfo', 'progpath prog title toporchild classname hndle'.split(' '))
 
 def getProgInfo(modInfo=None):
     """returns program info as namedtuple (progpath, prog, title, toporchild, classname, hndle)
 
+
     now length 6, including the classname, but also a named tuple!!
 
     prog always lowercase
@@ -215,21 +216,21 @@ def getProgInfo(modInfo=None):
 
     toporchild 'top' or 'child', or '' if no valid window
     """
-    #pylint:disable=W0702    
-    try:
-        modInfo = modInfo or natlink.getCurrentModule()
-    except:
-        print(f'natlink.getCurrentModule failed: {sys.exc_info()[0]}:\n\t"{sys.exc_info()[1]}"')
-        print("===get modInfo via autohotkeyactions.getModInfo")
-        print("===todo  in autohotkeyactions.getModInfo")
-        # modInfo = autohotkeyactions.getModInfo()
-        print("===modInfo via autohotkeyactions: ", repr(modInfo))
+    #pylint:disable=W0702
+    if modInfo is None:
+        try:
+            modInfo = natlink.getCurrentModule()
+        # print("modInfo through natlink: %s"% repr(modInfo))
+        except natlink.NatError:
+            progInfo = autohotkeyactions.getProgInfo()
+            return progInfo
+    
     _hndle = modInfo[2]
     if not _hndle:
         ## assume desktop, no foreground window, treat as top...
         return ProgInfo("", "", "", "top", "", 0)
     progpath = modInfo[0]
-    prog = getBaseNameLower(modInfo[0])
+    prog = Path(modInfo[0].lower()).stem
     title = modInfo[1]
     if isTopWindow(modInfo[2]):
         toporchild = 'top'
@@ -352,7 +353,7 @@ def ExecScript(script, callingFrom=None):
     global pendingExecScripts
     if callingFrom and (getattr(callingFrom, 'status', '') == 'new' or
                         getattr(callingFrom, 'inGotBegin', 0)):
-        print('pending execScript for %s, %s'% (callingFrom.getName(), script))
+        print(f'pending execScript for {callingFrom.getName()}')
         pendingExecScripts.append(script)
         return None
                             
@@ -978,8 +979,8 @@ def printMousePosition(absorrel, printAll = 0):
         print('RELATIVE MOUSE POSITIONS:')
     else:
         print('ABSOLUTE MOUSE POSITIONS:')
-    for which in whichDict:
-        print('---related to %s:'% whichDict[which].upper())
+    for _, which in whichDict.items():
+        print('---related to %s:'% which.upper())
         for cornerPos in cornerRange:
             print("%s: %s"% (cornerDict[cornerPos], getMousePositionActionString(absorrel, which, cornerPos)))
         if printAll:
@@ -1429,7 +1430,7 @@ def deleteWordIfNecessary(w):
 
 if DEBUG:
     fOutName = 'c:\\DEBUG '+__name__+'.txt'
-    debugFile = open(fOutName, 'w')
+    debugFile = open(fOutName, 'w', encoding='utf-8')
     print('DEBUG uitvoer naar: %s'% fOutName)
 
 def debugPrint(t):
@@ -1636,7 +1637,6 @@ def saveClipboard():
     #pylint:disable=W0702    
     # global previousClipboardText
     t = getClipboard()
-    print('clipboard contents to "previousClipboardText": %s'% t)
     previousClipboardText.append(t)
     for _i in range(10):
         try:
@@ -1676,6 +1676,8 @@ def clearClipboard():
         win32clipboard.CloseClipboard()
     # print 'clearClipboard: %.4f'% (time.time() - t0,)
 
+format_unicode = win32con.CF_UNICODETEXT
+
 def restoreClipboard():
     """Restores the previously saved clipboard text into the clipboard
 
@@ -1702,8 +1704,7 @@ def restoreClipboard():
             return
     win32clipboard.EmptyClipboard()
     if t:
-        #print 'restoring clipboard to: %s'% t
-        win32clipboard.SetClipboardData(1, t)
+        win32clipboard.SetClipboardData(format_unicode, t)
     win32clipboard.CloseClipboard()
 
 def getClipboard():
@@ -1836,8 +1837,8 @@ def add2logfile(word, filename):
     if not logFile:
         return # silent
     try:
-        f = open(os.path.join(logFolder, filename), 'a')
-        f.write(word + '\n')
+        with open(os.path.join(logFolder, filename), 'a', encoding='utf-8') as fp:
+            fp.write(word + '\n')
         print('written to %s: %s' % (os.path.join(logFolder), filename))
     except:
         pass
